<?php
/**
 * The template for displaying Comments.
 *
 * The area of the page that contains both current comments
 * and the comment form. The actual display of comments is
 * handled by a callback to xena_comment() which is
 * located in the inc/template-tags.php file.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/*
 * If the current post is protected by a password and
 * the visitor has not yet entered the password we will
 * return early without loading the comments.
 */
if ( post_password_required() ) {
	return;
}

/**
 * Xena_before_comments hook.
 *
 * @since 1.0.0
 */
do_action( 'xena_before_comments' );
?>
<div id="comments">

	<?php
	/**
	 * Xena_inside_comments hook.
	 *
	 * @since 1.0.0
	 */
	do_action( 'xena_inside_comments' );

	if ( have_comments() ) : 
		?>
		<h3 class="comments-title">
			<?php
			$xena_comments_number = get_comments_number();
			$xena_comments_title  = apply_filters(
				'xena_comment_form_title',
				sprintf(
					esc_html(
					/* translators: 1: number of comments, 2: post title */
						_nx(
							'%1$s thought on &ldquo;%2$s&rdquo;',
							'%1$s thoughts on &ldquo;%2$s&rdquo;',
							$xena_comments_number,
							'comments title',
							'xena'
						) 
					),
					number_format_i18n( $xena_comments_number ),
					get_the_title()
				) 
			);

			echo esc_html( $xena_comments_title );
			?>
		</h3>

		<?php
		/**
		 * Xena_below_comments_title hook.
		 *
		 * @since 1.0.0
		 */
		do_action( 'xena_below_comments_title' );

		if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : 
			?>
			<nav id="comment-nav-above" class="comment-navigation" role="navigation">
				<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'xena' ); ?></h2>
				<div class="nav-previous"><?php previous_comments_link( esc_html__( '&larr; Older Comments', 'xena' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( esc_html__( 'Newer Comments &rarr;', 'xena' ) ); ?></div>
			</nav><!-- #comment-nav-above -->
		<?php endif; ?>

		<ol class="comment-list">
			<?php
			/*
			 * Loop through and list the comments. Tell wp_list_comments()
			 * to use xena_comment() to format the comments.
			 * If you want to override this in a child theme, then you can
			 * define xena_comment() and that will be used instead.
			 * See xena_comment() in inc/template-tags.php for more.
			 */
			wp_list_comments(
				array(
					'callback' => 'xena_comment',
				) 
			);
			?>
		</ol><!-- .comment-list -->

		<?php if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) : ?>
			<nav id="comment-nav-below" class="comment-navigation" role="navigation">
				<h2 class="screen-reader-text"><?php esc_html_e( 'Comment navigation', 'xena' ); ?></h2>
				<div class="nav-previous"><?php previous_comments_link( __( '&larr; Older Comments', 'xena' ) ); ?></div>
				<div class="nav-next"><?php next_comments_link( __( 'Newer Comments &rarr;', 'xena' ) ); ?></div>
			</nav><!-- #comment-nav-below -->
			<?php 
		endif;

	endif;

	// If comments are closed and there are comments, let's leave a little note, shall we?
	if ( ! comments_open() && '0' !== get_comments_number() && post_type_supports( get_post_type(), 'comments' ) ) :
		?>
		<p class="no-comments"><?php esc_html_e( 'Comments are closed.', 'xena' ); ?></p>
		<?php 
	endif;

	comment_form();
	?>

</div><!-- #comments -->
