<?php
/**
 * Xena.
 *
 * Please do not make any edits to this file. All edits should be done in a child theme.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

// Set our theme version.
define( 'XENA_VERSION', '1.0.6' );

if ( ! function_exists( 'xena_setup' ) ) {
	add_action( 'after_setup_theme', 'xena_setup' );
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * @since 1.0.0
	 */
	function xena_setup() {
		// Make theme available for translation.
		load_theme_textdomain( 'xena' );

		// Add theme support for various features.
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link', 'status' ) );
		add_theme_support( 'woocommerce' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list', 'gallery', 'caption', 'script', 'style' ) );
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_theme_support( 'align-wide' );
		add_theme_support( 'responsive-embeds' );

		add_theme_support(
			'custom-logo',
			array(
				'height'      => 70,
				'width'       => 350,
				'flex-height' => true,
				'flex-width'  => true,
			) 
		);

		add_theme_support(
			'custom-background',
			apply_filters(
				'xena_custom_background_args',
				array(
					'default-color' => 'ffffff',
					'default-image' => '',
				)
			)
		);

		// Register primary menu.
		register_nav_menus(
			array(
				'primary' => esc_html__( 'Primary Menu', 'xena' ),
			) 
		);

		/**
		 * Set the content width to something large
		 * We set a more accurate width in xena_smart_content_width()
		 */
		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 1200; /* pixels */
		}

		// This theme styles the visual editor to resemble the theme style.
		add_editor_style( 'css/admin/editor-style.css' );
	}
}

/**
 * Get all necessary theme files
 */
$xena_theme_dir = get_template_directory();

require $xena_theme_dir . '/inc/theme-functions.php';
require $xena_theme_dir . '/inc/defaults.php';
require $xena_theme_dir . '/inc/class-xena-css.php';
require $xena_theme_dir . '/inc/css-output.php';
require $xena_theme_dir . '/inc/general.php';
require $xena_theme_dir . '/inc/customizer.php';
require $xena_theme_dir . '/inc/markup.php';
require $xena_theme_dir . '/inc/typography.php';
require $xena_theme_dir . '/inc/plugin-compat.php';
require $xena_theme_dir . '/inc/block-editor.php';
require $xena_theme_dir . '/inc/blog.php';

if ( is_admin() ) {
	require $xena_theme_dir . '/inc/meta-box.php';
}

/**
 * Load our theme structure
 */
require $xena_theme_dir . '/inc/structure/archives.php';
require $xena_theme_dir . '/inc/structure/comments.php';
require $xena_theme_dir . '/inc/structure/featured-images.php';
require $xena_theme_dir . '/inc/structure/footer.php';
require $xena_theme_dir . '/inc/structure/header.php';
require $xena_theme_dir . '/inc/structure/class-xena-page-walker.php';
require $xena_theme_dir . '/inc/structure/navigation.php';
require $xena_theme_dir . '/inc/structure/post-meta.php';
require $xena_theme_dir . '/inc/structure/sidebars.php';
