<?php
/**
 * Blog structure functions
 *
 * @package Xena
 */

add_filter( 'xena_page_header_default_size', 'xena_blog_page_header_default_size' );

/**
 * Set the default image size for page header to medium
 *
 * @param string $output size of header image.
 * @since 1.0.0
 */
function xena_blog_page_header_default_size( $output ) {
	// If we're not on any single post/page or the 404 template, we must be showing an archive.
	if ( ! is_singular() && ! is_404() ) {
		return 'medium';

	} else {
		return 'large';
	}

}

if ( ! function_exists( 'xena_blog_body_classes' ) ) {
	add_filter( 'body_class', 'xena_blog_body_classes' );
	/**
	 * Adds custom classes to the body
	 *
	 * @param array $classes class list.
	 *
	 * @since 1.0.0
	 */
	function xena_blog_body_classes( $classes ) {
		// align post-images to the left.
		$classes[] = 'xena';
		$classes[] = 'post-image-aligned-left';
		$classes[] = 'post-image-below-header';

		return $classes;
	}
}

if ( ! function_exists( 'xena_category_entry_meta' ) ) {

	add_action( 'xena_before_entry_title', 'xena_category_entry_meta' );

	/**
	 * Entry meta containing categories only
	 *
	 * @since 1.0.0
	 */
	function xena_category_entry_meta() {
		$items = apply_filters(
			'xena_before_header_entry_meta_items',
			array(
				'categories',
			) 
		);
		?>
		<div class="entry-meta">

			<?php
			foreach ( $items as $item ) {
				xena_do_post_meta_item( $item );
			}
			?>
		</div>
		<?php
	}
}

add_filter( 'comment_reply_link', 'xena_replace_reply_link_class' );


	/**
	 * Replace reply link
	 *
	 * @param string $class Class to add to link.
	 *
	 * @return mixed
	 */
function xena_replace_reply_link_class( $class ) {
	$class = str_replace( "class='comment-reply-link", "class='comment-reply-link button", $class );

	return $class;
}


if ( ! function_exists( 'xena_hr_separator' ) ) {
	add_action( 'xena_after_entry_content', 'xena_hr_separator', 20 );
	/**
	 * Add hr separator plus CSS
	 *
	 * @since 1.0.0
	 */
	function xena_hr_separator() {

		if ( ! is_single() ) {

			// add some css to reduce padding on left aligned image.
			?>
			<hr class="xena-divider">
			<?php
		}
	}
}
