<?php
/**
 * Builds our Customizer controls.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

add_action( 'customize_register', 'xena_set_customizer_helpers', 1 );
/**
 * Set up helpers early so they're always available.
 * Other modules might need access to them at some point.
 *
 * @since 1.0.0
 */
function xena_set_customizer_helpers() {
	require_once trailingslashit( get_template_directory() ) . 'inc/customizer/customizer-helpers.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound
}

if ( ! function_exists( 'xena_customize_register' ) ) {
	add_action( 'customize_register', 'xena_customize_register' );
	/**
	 * Add our base options to the Customizer.
	 *
	 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
	 */
	function xena_customize_register( $wp_customize ) {
		$defaults = xena_get_defaults();

		require_once trailingslashit( get_template_directory() ) . 'inc/customizer/customizer-helpers.php'; // phpcs:ignore WPThemeReview.CoreFunctionality.FileInclude.FileIncludeFound

		if ( $wp_customize->get_control( 'blogdescription' ) ) {
			$wp_customize->get_control( 'blogdescription' )->priority  = 3;
			$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';
		}

		if ( $wp_customize->get_control( 'blogname' ) ) {
			$wp_customize->get_control( 'blogname' )->priority  = 1;
			$wp_customize->get_setting( 'blogname' )->transport = 'postMessage';
		}

		if ( $wp_customize->get_control( 'custom_logo' ) ) {
			$wp_customize->get_setting( 'custom_logo' )->transport = 'refresh';
		}

		if ( method_exists( $wp_customize, 'register_control_type' ) ) {
			$wp_customize->register_control_type( 'Xena_Range_Slider_Control' );
		}

		if ( isset( $wp_customize->selective_refresh ) ) {
			$wp_customize->selective_refresh->add_partial(
				'blogname',
				array(
					'selector'        => '.main-title a',
					'render_callback' => 'xena_customize_partial_blogname',
				) 
			);

			$wp_customize->selective_refresh->add_partial(
				'blogdescription',
				array(
					'selector'        => '.site-description',
					'render_callback' => 'xena_customize_partial_blogdescription',
				) 
			);
		}

		$wp_customize->add_setting(
			'xena_settings[hide_title]',
			array(
				'default'           => $defaults['hide_title'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_checkbox',
			)
		);

		$wp_customize->add_control(
			'xena_settings[hide_title]',
			array(
				'type'     => 'checkbox',
				'label'    => esc_html__( 'Hide site title', 'xena' ),
				'section'  => 'title_tagline',
				'priority' => 2,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[hide_tagline]',
			array(
				'default'           => $defaults['hide_tagline'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_checkbox',
			)
		);

		$wp_customize->add_control(
			'xena_settings[hide_tagline]',
			array(
				'type'     => 'checkbox',
				'label'    => esc_html__( 'Hide site tagline', 'xena' ),
				'section'  => 'title_tagline',
				'priority' => 4,
			)
		);

		if ( ! function_exists( 'the_custom_logo' ) ) {
			$wp_customize->add_setting(
				'xena_settings[logo]',
				array(
					'default'           => $defaults['logo'],
					'type'              => 'option',
					'sanitize_callback' => 'esc_url_raw',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Image_Control(
					$wp_customize,
					'xena_settings[logo]',
					array(
						'label'    => esc_html__( 'Logo', 'xena' ),
						'section'  => 'title_tagline',
						'settings' => 'xena_settings[logo]',
					)
				)
			);
		}

		$wp_customize->add_setting(
			'xena_settings[retina_logo]',
			array(
				'default'           => $defaults['retina_logo'],
				'type'              => 'option',
				'sanitize_callback' => 'esc_url_raw',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Image_Control(
				$wp_customize,
				'xena_settings[retina_logo]',
				array(
					'label'           => esc_html__( 'Retina Logo', 'xena' ),
					'section'         => 'title_tagline',
					'settings'        => 'xena_settings[retina_logo]',
					'active_callback' => 'xena_has_custom_logo_callback',
				)
			)
		);

		$wp_customize->add_setting(
			'xena_settings[logo_width]',
			array(
				'default'           => $defaults['logo_width'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_empty_absint',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Xena_Range_Slider_Control(
				$wp_customize,
				'xena_settings[logo_width]',
				array(
					'label'           => esc_html__( 'Logo Width', 'xena' ),
					'section'         => 'title_tagline',
					'settings'        => array(
						'desktop' => 'xena_settings[logo_width]',
					),
					'choices'         => array(
						'desktop' => array(
							'min'  => 30,
							'max'  => 800,
							'step' => 10,
							'edit' => true,
							'unit' => 'px',
						),
					),
					'active_callback' => 'xena_has_custom_logo_callback',
				)
			)
		);

		$wp_customize->add_setting(
			'xena_settings[inline_logo_site_branding]',
			array(
				'default'           => $defaults['inline_logo_site_branding'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_checkbox',
			)
		);

		$wp_customize->add_control(
			'xena_settings[inline_logo_site_branding]',
			array(
				'type'            => 'checkbox',
				'label'           => esc_html__( 'Place logo next to title', 'xena' ),
				'section'         => 'title_tagline',
				'active_callback' => 'xena_has_logo_site_branding',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[text_color]',
			array(
				'default'           => $defaults['text_color'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_hex_color',
				'transport'         => 'refresh',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'xena_settings[text_color]',
				array(
					'label'    => esc_html__( 'Text Color', 'xena' ),
					'section'  => 'colors',
					'settings' => 'xena_settings[text_color]',
				)
			)
		);

		$wp_customize->add_setting(
			'xena_settings[link_color]',
			array(
				'default'           => $defaults['link_color'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_hex_color',
				'transport'         => 'refresh',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'xena_settings[link_color]',
				array(
					'label'    => esc_html__( 'Link and Accent Color', 'xena' ),
					'section'  => 'colors',
					'settings' => 'xena_settings[link_color]',
				)
			)
		);

		$wp_customize->add_setting(
			'xena_settings[link_color_hover]',
			array(
				'default'           => $defaults['link_color_hover'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_hex_color',
				'transport'         => 'refresh',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'xena_settings[link_color_hover]',
				array(
					'label'    => esc_html__( 'Link Color Hover', 'xena' ),
					'section'  => 'colors',
					'settings' => 'xena_settings[link_color_hover]',
				)
			)
		);

		$wp_customize->add_setting(
			'xena_settings[link_color_visited]',
			array(
				'default'           => $defaults['link_color_visited'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_hex_color',
				'transport'         => 'refresh',
			)
		);

		$wp_customize->add_control(
			new WP_Customize_Color_Control(
				$wp_customize,
				'xena_settings[link_color_visited]',
				array(
					'label'    => esc_html__( 'Link Color Visited', 'xena' ),
					'section'  => 'colors',
					'settings' => 'xena_settings[link_color_visited]',
				)
			)
		);

		$color_defaults = xena_get_color_defaults();

		if ( ! $wp_customize->get_setting( 'xena_settings[blog_post_title_color]' ) ) {
			$wp_customize->add_setting(
				'xena_settings[blog_post_title_color]',
				array(
					'default'           => $color_defaults['blog_post_title_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'blog_post_title_color',
					array(
						'label'    => esc_html__( 'Archive Post Title Color', 'xena' ),
						'section'  => 'colors',
						'settings' => 'xena_settings[blog_post_title_color]',
					)
				)
			);

			$wp_customize->add_setting(
				'xena_settings[blog_post_title_hover_color]',
				array(
					'default'           => $color_defaults['blog_post_title_hover_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,
					'blog_post_title_hover_color',
					array(
						'label'    => esc_html__( 'Archive Post Title Color Hover', 'xena' ),
						'section'  => 'colors',
						'settings' => 'xena_settings[blog_post_title_hover_color]',
					)
				)
			);
		}

		$wp_customize->add_setting(
			'nav_color_presets',
			array(
				'default'           => 'current',
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_preset_layout',
				'transport'         => 'postMessage',
			)
		);

		if ( ! $wp_customize->get_setting( 'xena_settings[navigation_background_color]' ) ) {
			$wp_customize->add_setting(
				'xena_settings[navigation_background_color]',
				array(
					'default'           => $color_defaults['navigation_background_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_rgba_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[navigation_text_color]',
				array(
					'default'           => $color_defaults['navigation_text_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[navigation_background_hover_color]',
				array(
					'default'           => $color_defaults['navigation_background_hover_color'],
					'type'              => 'option',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'xena_sanitize_rgba_color',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[navigation_text_hover_color]',
				array(
					'default'           => $color_defaults['navigation_text_hover_color'],
					'type'              => 'option',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'xena_sanitize_hex_color',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[navigation_background_current_color]',
				array(
					'default'           => $color_defaults['navigation_background_current_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_rgba_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[navigation_text_current_color]',
				array(
					'default'           => $color_defaults['navigation_text_current_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[subnavigation_background_color]',
				array(
					'default'           => $color_defaults['subnavigation_background_color'],
					'type'              => 'option',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'xena_sanitize_rgba_color',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[subnavigation_text_color]',
				array(
					'default'           => $color_defaults['subnavigation_text_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[subnavigation_background_hover_color]',
				array(
					'default'           => $color_defaults['subnavigation_background_hover_color'],
					'type'              => 'option',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'xena_sanitize_rgba_color',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[subnavigation_text_hover_color]',
				array(
					'default'           => $color_defaults['subnavigation_text_hover_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[subnavigation_background_current_color]',
				array(
					'default'           => $color_defaults['subnavigation_background_current_color'],
					'type'              => 'option',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'xena_sanitize_rgba_color',
				)
			);

			$wp_customize->add_setting(
				'xena_settings[subnavigation_text_current_color]',
				array(
					'default'           => $color_defaults['subnavigation_text_current_color'],
					'type'              => 'option',
					'sanitize_callback' => 'xena_sanitize_hex_color',
					'transport'         => 'postMessage',
				)
			);
		}



		if ( class_exists( 'WP_Customize_Panel' ) ) {
			if ( ! $wp_customize->get_panel( 'xena_layout_panel' ) ) {
				$wp_customize->add_panel(
					'xena_layout_panel',
					array(
						'priority' => 25,
						'title'    => esc_html__( 'Layout', 'xena' ),
					) 
				);
			}
		}

		$wp_customize->add_section(
			'xena_layout_container',
			array(
				'title'    => esc_html__( 'Container', 'xena' ),
				'priority' => 10,
				'panel'    => 'xena_layout_panel',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[container_width]',
			array(
				'default'           => $defaults['container_width'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_integer',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			new Xena_Range_Slider_Control(
				$wp_customize,
				'xena_settings[container_width]',
				array(
					'type'     => 'xena-range-slider',
					'label'    => esc_html__( 'Container Width', 'xena' ),
					'section'  => 'xena_layout_container',
					'settings' => array(
						'desktop' => 'xena_settings[container_width]',
					),
					'choices'  => array(
						'desktop' => array(
							'min'  => 700,
							'max'  => 2000,
							'step' => 5,
							'edit' => true,
							'unit' => 'px',
						),
					),
					'priority' => 0,
				)
			)
		);

		$wp_customize->add_section(
			'xena_top_bar',
			array(
				'title'    => esc_html__( 'Top Bar', 'xena' ),
				'priority' => 15,
				'panel'    => 'xena_layout_panel',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[top_bar_width]',
			array(
				'default'           => $defaults['top_bar_width'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[top_bar_width]',
			array(
				'type'            => 'select',
				'label'           => esc_html__( 'Top Bar Width', 'xena' ),
				'section'         => 'xena_top_bar',
				'choices'         => array(
					'full'      => esc_html__( 'Full', 'xena' ),
					'contained' => esc_html__( 'Contained', 'xena' ),
				),
				'settings'        => 'xena_settings[top_bar_width]',
				'priority'        => 5,
				'active_callback' => 'xena_is_top_bar_active',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[top_bar_inner_width]',
			array(
				'default'           => $defaults['top_bar_inner_width'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[top_bar_inner_width]',
			array(
				'type'            => 'select',
				'label'           => esc_html__( 'Top Bar Inner Width', 'xena' ),
				'section'         => 'xena_top_bar',
				'choices'         => array(
					'full'      => esc_html__( 'Full', 'xena' ),
					'contained' => esc_html__( 'Contained', 'xena' ),
				),
				'settings'        => 'xena_settings[top_bar_inner_width]',
				'priority'        => 10,
				'active_callback' => 'xena_is_top_bar_active',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[top_bar_alignment]',
			array(
				'default'           => $defaults['top_bar_alignment'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[top_bar_alignment]',
			array(
				'type'            => 'select',
				'label'           => __( 'Top Bar Alignment', 'xena' ),
				'section'         => 'xena_top_bar',
				'choices'         => array(
					'left'   => __( 'Left', 'xena' ),
					'center' => __( 'Center', 'xena' ),
					'right'  => __( 'Right', 'xena' ),
				),
				'settings'        => 'xena_settings[top_bar_alignment]',
				'priority'        => 15,
				'active_callback' => 'xena_is_top_bar_active',
			)
		);

		$wp_customize->add_section(
			'xena_layout_header',
			array(
				'title'    => __( 'Header', 'xena' ),
				'priority' => 20,
				'panel'    => 'xena_layout_panel',
			)
		);

		$wp_customize->add_setting(
			'xena_header_helper',
			array(
				'default'           => 'current',
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_preset_layout',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_header_helper',
			array(
				'type'      => 'select',
				'label'     => __( 'Header Presets', 'xena' ),
				'section'   => 'xena_layout_header',
				'choices'   => array(
					'current'               => __( 'Current', 'xena' ),
					'default'               => __( 'Default', 'xena' ),
					'nav-before-centered'   => __( 'Navigation Before - Centered', 'xena' ),
					'nav-after-centered'    => __( 'Navigation After - Centered', 'xena' ),
					'nav-right'             => __( 'Navigation Right', 'xena' ),
					'nav-left'              => __( 'Navigation Left', 'xena' ),
				),
				'settings'  => 'xena_header_helper',
				'priority'  => 4,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[header_layout_setting]',
			array(
				'default'           => $defaults['header_layout_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[header_layout_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Header Width', 'xena' ),
				'section'  => 'xena_layout_header',
				'choices'  => array(
					'fluid-header'     => __( 'Full', 'xena' ),
					'contained-header' => __( 'Contained', 'xena' ),
				),
				'settings' => 'xena_settings[header_layout_setting]',
				'priority' => 5,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[header_inner_width]',
			array(
				'default'           => $defaults['header_inner_width'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[header_inner_width]',
			array(
				'type'     => 'select',
				'label'    => __( 'Inner Header Width', 'xena' ),
				'section'  => 'xena_layout_header',
				'choices'  => array(
					'contained'  => __( 'Contained', 'xena' ),
					'full-width' => __( 'Full', 'xena' ),
				),
				'settings' => 'xena_settings[header_inner_width]',
				'priority' => 6,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[header_alignment_setting]',
			array(
				'default'           => $defaults['header_alignment_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[header_alignment_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Header Alignment', 'xena' ),
				'section'  => 'xena_layout_header',
				'choices'  => array(
					'left'   => __( 'Left', 'xena' ),
					'center' => __( 'Center', 'xena' ),
					'right'  => __( 'Right', 'xena' ),
				),
				'settings' => 'xena_settings[header_alignment_setting]',
				'priority' => 10,
			)
		);

		$wp_customize->add_section(
			'xena_layout_navigation',
			array(
				'title'    => __( 'Primary Navigation', 'xena' ),
				'priority' => 30,
				'panel'    => 'xena_layout_panel',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_layout_setting]',
			array(
				'default'           => $defaults['nav_layout_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[nav_layout_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Navigation Width', 'xena' ),
				'section'  => 'xena_layout_navigation',
				'choices'  => array(
					'fluid-nav'     => __( 'Full', 'xena' ),
					'contained-nav' => __( 'Contained', 'xena' ),
				),
				'settings' => 'xena_settings[nav_layout_setting]',
				'priority' => 15,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_inner_width]',
			array(
				'default'           => $defaults['nav_inner_width'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[nav_inner_width]',
			array(
				'type'     => 'select',
				'label'    => __( 'Inner Navigation Width', 'xena' ),
				'section'  => 'xena_layout_navigation',
				'choices'  => array(
					'contained'  => __( 'Contained', 'xena' ),
					'full-width' => __( 'Full', 'xena' ),
				),
				'settings' => 'xena_settings[nav_inner_width]',
				'priority' => 16,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_alignment_setting]',
			array(
				'default'           => $defaults['nav_alignment_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[nav_alignment_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Navigation Alignment', 'xena' ),
				'section'  => 'xena_layout_navigation',
				'choices'  => array(
					'left'   => __( 'Left', 'xena' ),
					'center' => __( 'Center', 'xena' ),
					'right'  => __( 'Right', 'xena' ),
				),
				'settings' => 'xena_settings[nav_alignment_setting]',
				'priority' => 20,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_position_setting]',
			array(
				'default'           => $defaults['nav_position_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => ( '' !== xena_get_option( 'nav_position_setting' ) ) ? 'postMessage' : 'refresh',
			)
		);

		$wp_customize->add_control(
			'xena_settings[nav_position_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Navigation Location', 'xena' ),
				'section'  => 'xena_layout_navigation',
				'choices'  => array(
					'nav-below-header'  => __( 'Below Header', 'xena' ),
					'nav-above-header'  => __( 'Above Header', 'xena' ),
					'nav-float-right'   => __( 'Float Right', 'xena' ),
					'nav-float-left'    => __( 'Float Left', 'xena' ),
					'nav-left-sidebar'  => __( 'Left Sidebar', 'xena' ),
					'nav-right-sidebar' => __( 'Right Sidebar', 'xena' ),
					''                  => __( 'No Navigation', 'xena' ),
				),
				'settings' => 'xena_settings[nav_position_setting]',
				'priority' => 22,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_drop_point]',
			array(
				'default'           => $defaults['nav_drop_point'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_empty_absint',
			)
		);

		$wp_customize->add_control(
			new Xena_Range_Slider_Control(
				$wp_customize,
				'xena_settings[nav_drop_point]',
				array(
					'label'           => __( 'Navigation Drop Point', 'xena' ),
					'sub_description' => __( 'The width when the navigation ceases to float and drops below your logo.', 'xena' ),
					'section'         => 'xena_layout_navigation',
					'settings'        => array(
						'desktop' => 'xena_settings[nav_drop_point]',
					),
					'choices'         => array(
						'desktop' => array(
							'min'  => 500,
							'max'  => 2000,
							'step' => 10,
							'edit' => true,
							'unit' => 'px',
						),
					),
					'priority'        => 22,
				)
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_dropdown_type]',
			array(
				'default'           => $defaults['nav_dropdown_type'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[nav_dropdown_type]',
			array(
				'type'     => 'select',
				'label'    => __( 'Navigation Dropdown', 'xena' ),
				'section'  => 'xena_layout_navigation',
				'choices'  => array(
					'hover'       => __( 'Hover', 'xena' ),
					'click'       => __( 'Click - Menu Item', 'xena' ),
					'click-arrow' => __( 'Click - Arrow', 'xena' ),
				),
				'settings' => 'xena_settings[nav_dropdown_type]',
				'priority' => 22,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_dropdown_direction]',
			array(
				'default'           => $defaults['nav_dropdown_direction'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[nav_dropdown_direction]',
			array(
				'type'     => 'select',
				'label'    => __( 'Dropdown Direction', 'xena' ),
				'section'  => 'xena_layout_navigation',
				'choices'  => array(
					'right' => __( 'Right', 'xena' ),
					'left'  => __( 'Left', 'xena' ),
				),
				'settings' => 'xena_settings[nav_dropdown_direction]',
				'priority' => 22,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[nav_search]',
			array(
				'default'           => $defaults['nav_search'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[nav_search]',
			array(
				'type'     => 'select',
				'label'    => __( 'Navigation Search', 'xena' ),
				'section'  => 'xena_layout_navigation',
				'choices'  => array(
					'enable'  => __( 'Enable', 'xena' ),
					'disable' => __( 'Disable', 'xena' ),
				),
				'settings' => 'xena_settings[nav_search]',
				'priority' => 23,
			)
		);

		$wp_customize->add_section(
			'xena_layout_sidebars',
			array(
				'title'    => __( 'Sidebars', 'xena' ),
				'priority' => 40,
				'panel'    => 'xena_layout_panel',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[layout_setting]',
			array(
				'default'           => $defaults['layout_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[layout_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Sidebar Layout', 'xena' ),
				'section'  => 'xena_layout_sidebars',
				'choices'  => array(
					'left-sidebar'  => __( 'Sidebar / Content', 'xena' ),
					'right-sidebar' => __( 'Content / Sidebar', 'xena' ),
					'no-sidebar'    => __( 'Content (no sidebars)', 'xena' ),
					'both-sidebars' => __( 'Sidebar / Content / Sidebar', 'xena' ),
					'both-left'     => __( 'Sidebar / Sidebar / Content', 'xena' ),
					'both-right'    => __( 'Content / Sidebar / Sidebar', 'xena' ),
				),
				'settings' => 'xena_settings[layout_setting]',
				'priority' => 30,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[blog_layout_setting]',
			array(
				'default'           => $defaults['blog_layout_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[blog_layout_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Blog Sidebar Layout', 'xena' ),
				'section'  => 'xena_layout_sidebars',
				'choices'  => array(
					'left-sidebar'  => __( 'Sidebar / Content', 'xena' ),
					'right-sidebar' => __( 'Content / Sidebar', 'xena' ),
					'no-sidebar'    => __( 'Content (no sidebars)', 'xena' ),
					'both-sidebars' => __( 'Sidebar / Content / Sidebar', 'xena' ),
					'both-left'     => __( 'Sidebar / Sidebar / Content', 'xena' ),
					'both-right'    => __( 'Content / Sidebar / Sidebar', 'xena' ),
				),
				'settings' => 'xena_settings[blog_layout_setting]',
				'priority' => 35,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[single_layout_setting]',
			array(
				'default'           => $defaults['single_layout_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[single_layout_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Single Post Sidebar Layout', 'xena' ),
				'section'  => 'xena_layout_sidebars',
				'choices'  => array(
					'left-sidebar'  => __( 'Sidebar / Content', 'xena' ),
					'right-sidebar' => __( 'Content / Sidebar', 'xena' ),
					'no-sidebar'    => __( 'Content (no sidebars)', 'xena' ),
					'both-sidebars' => __( 'Sidebar / Content / Sidebar', 'xena' ),
					'both-left'     => __( 'Sidebar / Sidebar / Content', 'xena' ),
					'both-right'    => __( 'Content / Sidebar / Sidebar', 'xena' ),
				),
				'settings' => 'xena_settings[single_layout_setting]',
				'priority' => 36,
			)
		);

		$wp_customize->add_section(
			'xena_layout_footer',
			array(
				'title'    => __( 'Footer', 'xena' ),
				'priority' => 50,
				'panel'    => 'xena_layout_panel',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[footer_layout_setting]',
			array(
				'default'           => $defaults['footer_layout_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[footer_layout_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Footer Width', 'xena' ),
				'section'  => 'xena_layout_footer',
				'choices'  => array(
					'fluid-footer'     => __( 'Full', 'xena' ),
					'contained-footer' => __( 'Contained', 'xena' ),
				),
				'settings' => 'xena_settings[footer_layout_setting]',
				'priority' => 40,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[footer_inner_width]',
			array(
				'default'           => $defaults['footer_inner_width'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[footer_inner_width]',
			array(
				'type'     => 'select',
				'label'    => __( 'Inner Footer Width', 'xena' ),
				'section'  => 'xena_layout_footer',
				'choices'  => array(
					'contained'  => __( 'Contained', 'xena' ),
					'full-width' => __( 'Full', 'xena' ),
				),
				'settings' => 'xena_settings[footer_inner_width]',
				'priority' => 41,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[footer_widget_setting]',
			array(
				'default'           => $defaults['footer_widget_setting'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[footer_widget_setting]',
			array(
				'type'     => 'select',
				'label'    => __( 'Footer Widgets', 'xena' ),
				'section'  => 'xena_layout_footer',
				'choices'  => array(
					'0' => '0',
					'1' => '1',
					'2' => '2',
					'3' => '3',
					'4' => '4',
					'5' => '5',
				),
				'settings' => 'xena_settings[footer_widget_setting]',
				'priority' => 45,
			)
		);

		$wp_customize->add_setting(
			'xena_settings[footer_bar_alignment]',
			array(
				'default'           => $defaults['footer_bar_alignment'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
				'transport'         => 'postMessage',
			)
		);

		$wp_customize->add_control(
			'xena_settings[footer_bar_alignment]',
			array(
				'type'            => 'select',
				'label'           => __( 'Footer Bar Alignment', 'xena' ),
				'section'         => 'xena_layout_footer',
				'choices'         => array(
					'left'   => __( 'Left', 'xena' ),
					'center' => __( 'Center', 'xena' ),
					'right'  => __( 'Right', 'xena' ),
				),
				'settings'        => 'xena_settings[footer_bar_alignment]',
				'priority'        => 47,
				'active_callback' => 'xena_is_footer_bar_active',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[back_to_top]',
			array(
				'default'           => $defaults['back_to_top'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_choices',
			)
		);

		$wp_customize->add_control(
			'xena_settings[back_to_top]',
			array(
				'type'     => 'select',
				'label'    => __( 'Back to Top Button', 'xena' ),
				'section'  => 'xena_layout_footer',
				'choices'  => array(
					'enable' => __( 'Enable', 'xena' ),
					''       => __( 'Disable', 'xena' ),
				),
				'settings' => 'xena_settings[back_to_top]',
				'priority' => 50,
			)
		);

		$wp_customize->add_section(
			'xena_blog_section',
			array(
				'title'    => __( 'Blog', 'xena' ),
				'priority' => 55,
				'panel'    => 'xena_layout_panel',
			)
		);

		$wp_customize->add_setting(
			'xena_settings[post_content]',
			array(
				'default'           => $defaults['post_content'],
				'type'              => 'option',
				'sanitize_callback' => 'xena_sanitize_blog_excerpt',
			)
		);

		$wp_customize->add_control(
			'blog_content_control',
			array(
				'type'     => 'select',
				'label'    => __( 'Content Type', 'xena' ),
				'section'  => 'xena_blog_section',
				'choices'  => array(
					'full'    => __( 'Full', 'xena' ),
					'excerpt' => __( 'Excerpt', 'xena' ),
				),
				'settings' => 'xena_settings[post_content]',
				'priority' => 10,
			)
		);

	}
}
