<?php
/**
 * Sets all of our theme defaults.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'xena_get_defaults' ) ) {
	/**
	 * Set default options
	 *
	 * @since 1.0.0
	 */
	function xena_get_defaults() {
		return apply_filters(
			'xena_option_defaults',
			array(
				'hide_title'                => false,
				'hide_tagline'              => false,
				'logo'                      => '',
				'inline_logo_site_branding' => false,
				'retina_logo'               => '',
				'logo_width'                => '',
				'top_bar_width'             => 'full',
				'top_bar_inner_width'       => 'contained',
				'top_bar_alignment'         => 'center',
				'container_width'           => '1200',
				'container_alignment'       => 'text',
				'header_layout_setting'     => 'fluid-header',
				'header_inner_width'        => 'contained',
				'nav_alignment_setting'     => 'left',
				'header_alignment_setting'  => 'left',
				'nav_layout_setting'        => 'fluid-nav',
				'nav_inner_width'           => 'contained',
				'nav_position_setting'      => 'nav-float-right',
				'nav_drop_point'            => '',
				'nav_dropdown_type'         => 'hover',
				'nav_dropdown_direction'    => 'right',
				'nav_search'                => 'disable',
				'content_layout_setting'    => 'one-container',
				'layout_setting'            => 'right-sidebar',
				'blog_layout_setting'       => 'right-sidebar',
				'single_layout_setting'     => 'right-sidebar',
				'post_content'              => 'excerpt',
				'footer_layout_setting'     => 'fluid-footer',
				'footer_inner_width'        => 'contained',
				'footer_widget_setting'     => '3',
				'footer_bar_alignment'      => 'right',
				'back_to_top'               => '',
				'text_color'                => '#444444',
				'link_color'                => '#af6e96',
				'link_color_hover'          => '#683f57',
				'link_color_visited'        => '',
				'icons'                     => 'svg',
				'dynamic_css_cache'         => true,
			)
		);
	}
}

if ( ! function_exists( 'xena_get_color_defaults' ) ) {
	/**
	 * Set default options
	 */
	function xena_get_color_defaults() {
		return apply_filters(
			'xena_color_option_defaults',
			array(
				'top_bar_background_color'               => '',
				'top_bar_text_color'                     => '',
				'top_bar_link_color'                     => '',
				'top_bar_link_color_hover'               => '',
				'header_background_color'                => '',
				'header_text_color'                      => '',
				'header_link_color'                      => '',
				'header_link_hover_color'                => '',
				'site_title_color'                       => '#444444',
				'site_tagline_color'                     => '',
				'navigation_background_color'            => '',
				'navigation_text_color'                  => '#444444',
				'navigation_background_hover_color'      => '',
				'navigation_text_hover_color'            => '',
				'navigation_background_current_color'    => '',
				'navigation_text_current_color'          => '',
				'subnavigation_background_color'         => '#ffffff',
				'subnavigation_text_color'               => '',
				'subnavigation_background_hover_color'   => '',
				'subnavigation_text_hover_color'         => '',
				'subnavigation_background_current_color' => '',
				'subnavigation_text_current_color'       => '',
				'navigation_search_background_color'     => '',
				'navigation_search_text_color'           => '#444444',
				'content_background_color'               => '',
				'content_text_color'                     => '',
				'content_link_color'                     => '',
				'content_link_hover_color'               => '',
				'content_title_color'                    => '',
				'blog_post_title_color'                  => '#444444',
				'blog_post_title_hover_color'            => '#444444',
				'entry_meta_text_color'                  => '#595959',
				'entry_meta_link_color'                  => '',
				'entry_meta_link_color_hover'            => '',
				'h1_color'                               => '#444444',
				'h2_color'                               => '#444444',
				'h3_color'                               => '#333333',
				'h4_color'                               => '#333333',
				'h5_color'                               => '#555555',
				'h6_color'                               => '#555555',
				'sidebar_widget_background_color'        => '',
				'sidebar_widget_text_color'              => '',
				'sidebar_widget_link_color'              => '',
				'sidebar_widget_link_hover_color'        => '',
				'sidebar_widget_title_color'             => '',
				'footer_widget_background_color'         => '',
				'footer_widget_text_color'               => '',
				'footer_widget_link_color'               => '',
				'footer_widget_link_hover_color'         => '',
				'footer_widget_title_color'              => '',
				'footer_background_color'                => '',
				'footer_text_color'                      => '',
				'footer_link_color'                      => '',
				'footer_link_hover_color'                => '',
				'form_background_color'                  => '',
				'form_text_color'                        => '',
				'form_background_color_focus'            => '',
				'form_text_color_focus'                  => '',
				'form_border_color'                      => '',
				'form_border_color_focus'                => '',
				'form_button_background_color'           => '#444444',
				'form_button_background_color_hover'     => '',
				'form_button_text_color'                 => '#ffffff',
				'form_button_text_color_hover'           => '#ffffff',
				'back_to_top_background_color'           => 'rgba( 0,0,0,0 )',
				'back_to_top_background_color_hover'     => 'rgba( 0,0,0,0 )',
				'back_to_top_text_color'                 => '#444444',
				'back_to_top_text_color_hover'           => '',
			)
		);
	}
}

if ( ! function_exists( 'xena_get_default_fonts' ) ) {
	/**
	 * Set default options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool $filter Whether to return the filtered values or original values.
	 * @return array Option defaults.
	 */
	function xena_get_default_fonts( $filter = true ) {
		$defaults = array(
			'font_body'                   => 'Open Sans',
			'font_body_category'          => 'sans-serif',
			'font_body_variants'          => 'regular,600,700',
			'body_font_weight'            => 'normal',
			'body_font_transform'         => 'none',
			'body_font_size'              => '18',
			'body_line_height'            => '2', // no unit.
			'paragraph_margin'            => '1.5', // em.
			'font_top_bar'                => 'inherit',
			'font_top_bar_category'       => '',
			'font_top_bar_variants'       => '',
			'top_bar_font_weight'         => 'normal',
			'top_bar_font_transform'      => 'none',
			'top_bar_font_size'           => '13',
			'font_site_title'             => 'inherit',
			'font_site_title_category'    => '',
			'font_site_title_variants'    => '',
			'site_title_font_weight'      => 'bold',
			'site_title_font_transform'   => 'none',
			'site_title_font_size'        => '45',
			'mobile_site_title_font_size' => '30',
			'font_site_tagline'           => 'inherit',
			'font_site_tagline_category'  => '',
			'font_site_tagline_variants'  => '',
			'site_tagline_font_weight'    => 'normal',
			'site_tagline_font_transform' => 'none',
			'site_tagline_font_size'      => '15',
			'font_navigation'             => 'inherit',
			'font_navigation_category'    => '',
			'font_navigation_variants'    => '',
			'navigation_font_weight'      => '600',
			'navigation_font_transform'   => 'uppercase',
			'navigation_font_size'        => '16',
			'font_widget_title'           => 'inherit',
			'font_widget_title_category'  => '',
			'font_widget_title_variants'  => '',
			'widget_title_font_weight'    => '700',
			'widget_title_font_transform' => 'none',
			'widget_title_font_size'      => '15',
			'widget_title_separator'      => '30',
			'widget_content_font_size'    => '15',
			'font_buttons'                => 'inherit',
			'font_buttons_category'       => '',
			'font_buttons_variants'       => '',
			'buttons_font_weight'         => 'normal',
			'buttons_font_transform'      => 'none',
			'buttons_font_size'           => '',
			'font_heading_1'              => 'inherit',
			'font_heading_1_category'     => '',
			'font_heading_1_variants'     => '',
			'heading_1_weight'            => '700',
			'heading_1_transform'         => 'none',
			'heading_1_font_size'         => '36',
			'heading_1_line_height'       => '1.25', // em.
			'heading_1_margin_bottom'     => '15',
			'mobile_heading_1_font_size'  => '34',
			'font_heading_2'              => 'inherit',
			'font_heading_2_category'     => '',
			'font_heading_2_variants'     => '',
			'heading_2_weight'            => '700',
			'heading_2_transform'         => 'none',
			'heading_2_font_size'         => '34',
			'heading_2_line_height'       => '1.25', // em.
			'heading_2_margin_bottom'     => '15',
			'mobile_heading_2_font_size'  => '32',
			'font_heading_3'              => 'inherit',
			'font_heading_3_category'     => '',
			'font_heading_3_variants'     => '',
			'heading_3_weight'            => '600',
			'heading_3_transform'         => 'none',
			'heading_3_font_size'         => '32',
			'heading_3_line_height'       => '1.25', // em.
			'heading_3_margin_bottom'     => '15',
			'font_heading_4'              => 'inherit',
			'font_heading_4_category'     => '',
			'font_heading_4_variants'     => '',
			'heading_4_weight'            => '600',
			'heading_4_transform'         => 'none',
			'heading_4_font_size'         => '28',
			'heading_4_line_height'       => '1.25', // em.
			'font_heading_5'              => 'inherit',
			'font_heading_5_category'     => '',
			'font_heading_5_variants'     => '',
			'heading_5_weight'            => '700',
			'heading_5_transform'         => 'none',
			'heading_5_font_size'         => '16',
			'heading_5_line_height'       => '1.25', // em.
			'font_heading_6'              => 'inherit',
			'font_heading_6_category'     => '',
			'font_heading_6_variants'     => '',
			'heading_6_weight'            => '700',
			'heading_6_transform'         => 'none',
			'heading_6_font_size'         => '16',
			'heading_6_line_height'       => '1.25', // em.
			'font_footer'                 => 'inherit',
			'font_footer_category'        => '',
			'font_footer_variants'        => '',
			'footer_weight'               => 'normal',
			'footer_transform'            => 'none',
			'footer_font_size'            => '15',
		);

		if ( $filter ) {
			return apply_filters( 'xena_font_option_defaults', $defaults );
		}

		return $defaults;
	}
}

if ( ! function_exists( 'xena_spacing_get_defaults' ) ) {
	/**
	 * Set the default options.
	 *
	 * @since 1.0.0
	 *
	 * @param bool $filter Whether to return the filtered values or original values.
	 * @return array Option defaults.
	 */
	function xena_spacing_get_defaults( $filter = true ) {
		$defaults = array(
			'top_bar_top'                    => '10',
			'top_bar_right'                  => '10',
			'top_bar_bottom'                 => '10',
			'top_bar_left'                   => '10',
			'header_top'                     => '40',
			'header_right'                   => '40',
			'header_bottom'                  => '40',
			'header_left'                    => '40',
			'menu_item'                      => '20',
			'menu_item_height'               => '60',
			'sub_menu_item_height'           => '10',
			'sub_menu_width'                 => '200',
			'content_top'                    => '40',
			'content_right'                  => '40',
			'content_bottom'                 => '40',
			'content_left'                   => '40',
			'mobile_content_top'             => '30',
			'mobile_content_right'           => '30',
			'mobile_content_bottom'          => '30',
			'mobile_content_left'            => '30',
			'separator'                      => '20',
			'mobile_separator'               => '',
			'left_sidebar_width'             => '25',
			'right_sidebar_width'            => '25',
			'widget_top'                     => '40',
			'widget_right'                   => '40',
			'widget_bottom'                  => '40',
			'widget_left'                    => '40',
			'footer_widget_container_top'    => '40',
			'footer_widget_container_right'  => '40',
			'footer_widget_container_bottom' => '40',
			'footer_widget_container_left'   => '40',
			'footer_widget_separator'        => '40',
			'footer_top'                     => '20',
			'footer_right'                   => '20',
			'footer_bottom'                  => '20',
			'footer_left'                    => '20',
		);

		if ( $filter ) {
			return apply_filters( 'xena_spacing_option_defaults', $defaults );
		}

		return $defaults;
	}
}

if ( ! function_exists( 'xena_typography_default_fonts' ) ) {
	/**
	 * Set the default system fonts.
	 *
	 * @since 1.0.0
	 */
	function xena_typography_default_fonts() {
		$fonts = array(
			'inherit',
			'System Stack',
			'Arial, Helvetica, sans-serif',
			'Century Gothic',
			'Comic Sans MS',
			'Courier New',
			'Georgia, Times New Roman, Times, serif',
			'Helvetica',
			'Impact',
			'Lucida Console',
			'Lucida Sans Unicode',
			'Palatino Linotype',
			'Segoe UI, Helvetica Neue, Helvetica, sans-serif',
			'Tahoma, Geneva, sans-serif',
			'Trebuchet MS, Helvetica, sans-serif',
			'Verdana, Geneva, sans-serif',
		);

		return apply_filters( 'xena_typography_default_fonts', $fonts );
	}
}


