<?php
/**
 * Builds our main Layout meta box.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

add_action( 'admin_enqueue_scripts', 'xena_enqueue_meta_box_scripts' );
/**
 * Adds any scripts for this meta box.
 *
 * @since 1.0.0
 *
 * @param string $hook The current admin page.
 */
function xena_enqueue_meta_box_scripts( $hook ) {
	if ( in_array( $hook, array( 'post.php', 'post-new.php' ), true ) ) {
		$post_types = get_post_types( array( 'public' => true ) );
		$screen     = get_current_screen();
		$post_type  = $screen->id;

		if ( in_array( $post_type, (array) $post_types, true ) ) {
			wp_enqueue_style( 'xena-layout-metabox', get_template_directory_uri() . '/css/admin/meta-box.css', array(), XENA_VERSION );
		}
	}
}

add_action( 'add_meta_boxes', 'xena_register_layout_meta_box' );
/**
 * Generate the layout metabox
 *
 * @since 1.0.0
 */
function xena_register_layout_meta_box() {
	if ( ! current_user_can( apply_filters( 'xena_metabox_capability', 'edit_theme_options' ) ) ) {
		return;
	}

	if ( ! defined( 'XENA_LAYOUT_META_BOX' ) ) {
		define( 'XENA_LAYOUT_META_BOX', true );
	}

	$post_types = get_post_types( array( 'public' => true ) );

	foreach ( $post_types as $type ) {
		if ( 'attachment' !== $type ) {
			add_meta_box(
				'xena_layout_options_meta_box',
				esc_html__( 'Layout', 'xena' ),
				'xena_do_layout_meta_box',
				$type,
				'side'
			);
		}
	}
}

/**
 * Build our meta box.
 *
 * @since 1.0.0
 *
 * @param object $post All post information.
 */
function xena_do_layout_meta_box( $post ) {
	wp_nonce_field( basename( __FILE__ ), 'xena_layout_nonce' );
	$stored_meta                                 = (array) get_post_meta( $post->ID );
	$stored_meta['_xena-sidebar-layout-meta'][0] = ( isset( $stored_meta['_xena-sidebar-layout-meta'][0] ) ) ? $stored_meta['_xena-sidebar-layout-meta'][0] : '';
	$stored_meta['_xena-footer-widget-meta'][0]  = ( isset( $stored_meta['_xena-footer-widget-meta'][0] ) ) ? $stored_meta['_xena-footer-widget-meta'][0] : '';
	$stored_meta['_xena-full-width-content'][0]  = ( isset( $stored_meta['_xena-full-width-content'][0] ) ) ? $stored_meta['_xena-full-width-content'][0] : '';
	$stored_meta['_xena-disable-headline'][0]    = ( isset( $stored_meta['_xena-disable-headline'][0] ) ) ? $stored_meta['_xena-disable-headline'][0] : '';

	$tabs = apply_filters(
		'xena_metabox_tabs',
		array(
			'sidebars' => array(
				'title'  => esc_html__( 'Sidebars', 'xena' ),
				'target' => '#xena-layout-sidebars',
				'class'  => 'current',
			),
			'footer_widgets' => array(
				'title'  => esc_html__( 'Footer Widgets', 'xena' ),
				'target' => '#xena-layout-footer-widgets',
				'class'  => '',
			),
			'disable_elements' => array(
				'title'  => esc_html__( 'Disable Elements', 'xena' ),
				'target' => '#xena-layout-disable-elements',
				'class'  => '',
			),
			'container' => array(
				'title'  => esc_html__( 'Page Builder Container', 'xena' ),
				'target' => '#xena-layout-page-builder-container',
				'class'  => '',
			),
		)
	);
	?>
	<script>
		jQuery(document).ready(function($) {
			$( '.xena-meta-box-menu li a' ).on( 'click', function( event ) {
				event.preventDefault();
				$( this ).parent().addClass( 'current' );
				$( this ).parent().siblings().removeClass( 'current' );
				var tab = $( this ).attr( 'data-target' );

				// Page header module still using href.
				if ( ! tab ) {
					tab = $( this ).attr( 'href' );
				}

				$( '.xena-meta-box-content' ).children( 'div' ).not( tab ).css( 'display', 'none' );
				$( tab ).fadeIn( 100 );
			});
		});
	</script>
	<div id="xena-meta-box-container">
		<ul class="xena-meta-box-menu">
			<?php
			foreach ( (array) $tabs as $tab => $data ) {
				echo '<li class="' . esc_attr( $data['class'] ) . '"><a data-target="' . esc_attr( $data['target'] ) . '" href="#">' . esc_html( $data['title'] ) . '</a></li>';
			}

			do_action( 'xena_layout_meta_box_menu_item' );
			?>
		</ul>
		<div class="xena-meta-box-content">
			<div id="xena-layout-sidebars">
				<div class="xena_layouts">
					<label for="meta-xena-layout-global" style="display:block;margin-bottom:10px;">
						<input type="radio" name="_xena-sidebar-layout-meta" id="meta-xena-layout-global" value="" <?php checked( $stored_meta['_xena-sidebar-layout-meta'][0], '' ); ?>>
						<?php esc_html_e( 'Default', 'xena' ); ?>
					</label>

					<label for="meta-xena-layout-one" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( 'Right Sidebar', 'xena' ); ?>">
						<input type="radio" name="_xena-sidebar-layout-meta" id="meta-xena-layout-one" value="right-sidebar" <?php checked( $stored_meta['_xena-sidebar-layout-meta'][0], 'right-sidebar' ); ?>>
						<?php esc_html_e( 'Content', 'xena' ); ?> / <strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong>
					</label>

					<label for="meta-xena-layout-two" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( 'Left Sidebar', 'xena' ); ?>">
						<input type="radio" name="_xena-sidebar-layout-meta" id="meta-xena-layout-two" value="left-sidebar" <?php checked( $stored_meta['_xena-sidebar-layout-meta'][0], 'left-sidebar' ); ?>>
						<strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong> / <?php esc_html_e( 'Content', 'xena' ); ?>
					</label>

					<label for="meta-xena-layout-three" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( 'No Sidebars', 'xena' ); ?>">
						<input type="radio" name="_xena-sidebar-layout-meta" id="meta-xena-layout-three" value="no-sidebar" <?php checked( $stored_meta['_xena-sidebar-layout-meta'][0], 'no-sidebar' ); ?>>
						<?php esc_html_e( 'Content (no sidebars)', 'xena' ); ?>
					</label>

					<label for="meta-xena-layout-four" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( 'Both Sidebars', 'xena' ); ?>">
						<input type="radio" name="_xena-sidebar-layout-meta" id="meta-xena-layout-four" value="both-sidebars" <?php checked( $stored_meta['_xena-sidebar-layout-meta'][0], 'both-sidebars' ); ?>>
						<strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong> / <?php esc_html_e( 'Content', 'xena' ); ?> / <strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong>
					</label>

					<label for="meta-xena-layout-five" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( 'Both Sidebars on Left', 'xena' ); ?>">
						<input type="radio" name="_xena-sidebar-layout-meta" id="meta-xena-layout-five" value="both-left" <?php checked( $stored_meta['_xena-sidebar-layout-meta'][0], 'both-left' ); ?>>
						<strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong> / <strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong> / <?php esc_html_e( 'Content', 'xena' ); ?>
					</label>

					<label for="meta-xena-layout-six" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( 'Both Sidebars on Right', 'xena' ); ?>">
						<input type="radio" name="_xena-sidebar-layout-meta" id="meta-xena-layout-six" value="both-right" <?php checked( $stored_meta['_xena-sidebar-layout-meta'][0], 'both-right' ); ?>>
						<?php esc_html_e( 'Content', 'xena' ); ?> / <strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong> / <strong><?php echo esc_html_x( 'Sidebar', 'Short name for meta box', 'xena' ); ?></strong>
					</label>
				</div>
			</div>
			<div id="xena-layout-footer-widgets" style="display: none;">
				<div class="xena_footer_widget">
					<label for="meta-xena-footer-widget-global" style="display:block;margin-bottom:10px;">
						<input type="radio" name="_xena-footer-widget-meta" id="meta-xena-footer-widget-global" value="" <?php checked( $stored_meta['_xena-footer-widget-meta'][0], '' ); ?>>
						<?php esc_html_e( 'Default', 'xena' ); ?>
					</label>

					<label for="meta-xena-footer-widget-zero" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( '0 Widgets', 'xena' ); ?>">
						<input type="radio" name="_xena-footer-widget-meta" id="meta-xena-footer-widget-zero" value="0" <?php checked( $stored_meta['_xena-footer-widget-meta'][0], '0' ); ?>>
						<?php esc_html_e( '0 Widgets', 'xena' ); ?>
					</label>

					<label for="meta-xena-footer-widget-one" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( '1 Widget', 'xena' ); ?>">
						<input type="radio" name="_xena-footer-widget-meta" id="meta-xena-footer-widget-one" value="1" <?php checked( $stored_meta['_xena-footer-widget-meta'][0], '1' ); ?>>
						<?php esc_html_e( '1 Widget', 'xena' ); ?>
					</label>

					<label for="meta-xena-footer-widget-two" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( '2 Widgets', 'xena' ); ?>">
						<input type="radio" name="_xena-footer-widget-meta" id="meta-xena-footer-widget-two" value="2" <?php checked( $stored_meta['_xena-footer-widget-meta'][0], '2' ); ?>>
						<?php esc_html_e( '2 Widgets', 'xena' ); ?>
					</label>

					<label for="meta-xena-footer-widget-three" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( '3 Widgets', 'xena' ); ?>">
						<input type="radio" name="_xena-footer-widget-meta" id="meta-xena-footer-widget-three" value="3" <?php checked( $stored_meta['_xena-footer-widget-meta'][0], '3' ); ?>>
						<?php esc_html_e( '3 Widgets', 'xena' ); ?>
					</label>

					<label for="meta-xena-footer-widget-four" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( '4 Widgets', 'xena' ); ?>">
						<input type="radio" name="_xena-footer-widget-meta" id="meta-xena-footer-widget-four" value="4" <?php checked( $stored_meta['_xena-footer-widget-meta'][0], '4' ); ?>>
						<?php esc_html_e( '4 Widgets', 'xena' ); ?>
					</label>

					<label for="meta-xena-footer-widget-five" style="display:block;margin-bottom:3px;" title="<?php esc_attr_e( '5 Widgets', 'xena' ); ?>">
						<input type="radio" name="_xena-footer-widget-meta" id="meta-xena-footer-widget-five" value="5" <?php checked( $stored_meta['_xena-footer-widget-meta'][0], '5' ); ?>>
						<?php esc_html_e( '5 Widgets', 'xena' ); ?>
					</label>
				</div>
			</div>
			<div id="xena-layout-page-builder-container" style="display: none;">
				<p class="page-builder-content" style="color:#666;font-size:13px;margin-top:0;">
					<?php esc_html_e( 'Choose your page builder content container type. Both options remove the content padding for you.', 'xena' ); ?>
				</p>

				<p class="xena_full_width_template">
					<label for="default-content" style="display:block;margin-bottom:10px;">
						<input type="radio" name="_xena-full-width-content" id="default-content" value="" <?php checked( $stored_meta['_xena-full-width-content'][0], '' ); ?>>
						<?php esc_html_e( 'Default', 'xena' ); ?>
					</label>

					<label id="full-width-content" for="_xena-full-width-content" style="display:block;margin-bottom:10px;">
						<input type="radio" name="_xena-full-width-content" id="_xena-full-width-content" value="true" <?php checked( $stored_meta['_xena-full-width-content'][0], 'true' ); ?>>
						<?php esc_html_e( 'Full Width', 'xena' ); ?>
					</label>

					<label id="xena-remove-padding" for="_xena-remove-content-padding" style="display:block;margin-bottom:10px;">
						<input type="radio" name="_xena-full-width-content" id="_xena-remove-content-padding" value="contained" <?php checked( $stored_meta['_xena-full-width-content'][0], 'contained' ); ?>>
						<?php esc_html_e( 'Contained', 'xena' ); ?>
					</label>
				</p>
			</div>
			<div id="xena-layout-disable-elements" style="display: none;">
				<?php if ( ! defined( 'xena_DE_VERSION' ) ) : ?>
					<div class="xena_disable_elements">
						<label for="meta-xena-disable-headline" style="display:block;margin: 0 0 1em;" title="<?php esc_attr_e( 'Content Title', 'xena' ); ?>">
							<input type="checkbox" name="_xena-disable-headline" id="meta-xena-disable-headline" value="true" <?php checked( $stored_meta['_xena-disable-headline'][0], 'true' ); ?>>
							<?php esc_html_e( 'Content Title', 'xena' ); ?>
						</label>
					</div>
				<?php endif; ?>

				<?php do_action( 'xena_layout_disable_elements_section', $stored_meta ); ?>
			</div>
			<?php do_action( 'xena_layout_meta_box_content', $stored_meta ); ?>
		</div>
	</div>
	<?php
}

add_action( 'save_post', 'xena_save_layout_meta_data' );
/**
 * Saves the sidebar layout meta data.
 *
 * @param int $post_id The Post ID.
 *
 * @since 1.0.0
 */
function xena_save_layout_meta_data( $post_id ) {
	$is_autosave    = wp_is_post_autosave( $post_id );
	$is_revision    = wp_is_post_revision( $post_id );
	$is_valid_nonce = ( isset( $_POST['xena_layout_nonce'] ) && wp_verify_nonce( sanitize_key( $_POST['xena_layout_nonce'] ), basename( __FILE__ ) ) ) ? true : false;

	if ( $is_autosave || $is_revision || ! $is_valid_nonce ) {
		return;
	}

	if ( ! current_user_can( 'edit_post', $post_id ) ) {
		return $post_id;
	}

	$sidebar_layout_key   = '_xena-sidebar-layout-meta';
	$sidebar_layout_value = filter_input( INPUT_POST, $sidebar_layout_key, FILTER_SANITIZE_STRING );

	if ( $sidebar_layout_value ) {
		update_post_meta( $post_id, $sidebar_layout_key, $sidebar_layout_value );
	} else {
		delete_post_meta( $post_id, $sidebar_layout_key );
	}

	$footer_widget_key   = '_xena-footer-widget-meta';
	$footer_widget_value = filter_input( INPUT_POST, $footer_widget_key, FILTER_SANITIZE_STRING );

	// Check for empty string to allow 0 as a value.
	if ( '' !== $footer_widget_value ) {
		update_post_meta( $post_id, $footer_widget_key, $footer_widget_value );
	} else {
		delete_post_meta( $post_id, $footer_widget_key );
	}

	$page_builder_container_key   = '_xena-full-width-content';
	$page_builder_container_value = filter_input( INPUT_POST, $page_builder_container_key, FILTER_SANITIZE_STRING );

	if ( $page_builder_container_value ) {
		update_post_meta( $post_id, $page_builder_container_key, $page_builder_container_value );
	} else {
		delete_post_meta( $post_id, $page_builder_container_key );
	}

	// We only need this if the Disable Elements module doesn't exist.
	if ( ! defined( 'xena_DE_VERSION' ) ) {
		$disable_content_title_key   = '_xena-disable-headline';
		$disable_content_title_value = filter_input( INPUT_POST, $disable_content_title_key, FILTER_SANITIZE_STRING );

		if ( $disable_content_title_value ) {
			update_post_meta( $post_id, $disable_content_title_key, $disable_content_title_value );
		} else {
			delete_post_meta( $post_id, $disable_content_title_key );
		}
	}

	do_action( 'xena_layout_meta_box_save', $post_id );
}
