<?php
/**
 * Archive elements.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'xena_archive_title' ) ) {
	add_action( 'xena_archive_title', 'xena_archive_title' );
	/**
	 * Build the archive title
	 *
	 * @since 1.0.0
	 */
	function xena_archive_title() {
		if ( ! function_exists( 'the_archive_title' ) ) {
			return;
		}

		$clearfix = is_author() ? ' clearfix' : '';
		?>
		<header class="page-header<?php echo esc_attr( $clearfix ); ?>">
		<?php
			/**
			 * Xena_before_archive_title hook.
			 *
			 * @since 1.0.0
			 */
			do_action( 'xena_before_archive_title' );
		?>

			<h1 class="page-title">
				<?php the_archive_title(); ?>
			</h1>

			<?php
			/**
			 * Xena_after_archive_title hook.
			 *
			 * @since 1.0.0
			 *
			 * @hooked xena_do_archive_description - 10
			 */
			do_action( 'xena_after_archive_title' );
			?>
		</header><!-- .page-header -->
		<?php
	}
}

if ( ! function_exists( 'xena_filter_the_archive_title' ) ) {
	add_filter( 'get_the_archive_title', 'xena_filter_the_archive_title' );
	/**
	 * Alter the_archive_title() function to match our original archive title function
	 *
	 * @since 1.0.0
	 *
	 * @param string $title The archive title.
	 * @return string The altered archive title.
	 */
	function xena_filter_the_archive_title( $title ) {
		if ( is_category() ) {
			$title = single_cat_title( '', false );
		} elseif ( is_tag() ) {
			$title = single_tag_title( '', false );
		} elseif ( is_author() ) {
			/*
			 * Queue the first post, that way we know
			 * what author we're dealing with (if that is the case).
			 */
			the_post();
			$title = sprintf(
				'%1$s<span class="vcard">%2$s</span>',
				get_avatar( get_the_author_meta( 'ID' ), 75 ),
				get_the_author()
			);

			/*
			 * Since we called the_post() above, we need to
			 * rewind the loop back to the beginning that way
			 * we can run the loop properly, in full.
			 */
			rewind_posts();
		}

		return $title;

	}
}

add_action( 'xena_after_archive_title', 'xena_do_archive_description' );
/**
 * Output the archive description.
 *
 * @since 1.0.0
 */
function xena_do_archive_description() {
	$term_description = term_description();

	if ( ! empty( $term_description ) ) {
		printf( '<div class="taxonomy-description">%s</div>', $term_description ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}

	if ( get_the_author_meta( 'description' ) && is_author() ) {
		echo '<div class="author-info">' . get_the_author_meta( 'description' ) . '</div>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}

	/**
	 * Xena_after_archive_description hook.
	 *
	 * @since 1.0.0
	 */
	do_action( 'xena_after_archive_description' );
}
