<?php
/**
 * Footer elements.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'xena_construct_footer' ) ) {
	add_action( 'xena_footer', 'xena_construct_footer' );
	/**
	 * Build our footer.
	 *
	 * @since 1.0.0
	 */
	function xena_construct_footer() {
		?>
		<footer class="site-info" <?php xena_do_microdata( 'footer' ); ?>>
			<div class="inside-site-info 
			<?php 
			if ( 'full-width' !== xena_get_option( 'footer_inner_width' ) ) :
				?>
				grid-container grid-parent<?php endif; ?>">
				<?php
				/**
				 * Xena_before_copyright hook.
				 *
				 * @since 1.0.0
				 *
				 * @hooked xena_footer_bar - 15
				 */
				do_action( 'xena_before_copyright' );
				?>
				<div class="copyright-bar">
					<?php
					/**
					 * Xena_credits hook.
					 *
					 * @since 1.0.0
					 *
					 * @hooked xena_add_footer_info - 10
					 */
					do_action( 'xena_credits' );
					?>
				</div>
			</div>
		</footer><!-- .site-info -->
		<?php
	}
}

if ( ! function_exists( 'xena_footer_bar' ) ) {
	add_action( 'xena_before_copyright', 'xena_footer_bar', 15 );
	/**
	 * Build our footer bar
	 *
	 * @since 1.0.0
	 */
	function xena_footer_bar() {
		if ( ! is_active_sidebar( 'footer-bar' ) ) {
			return;
		}
		?>
		<div class="footer-bar">
			<?php dynamic_sidebar( 'footer-bar' ); ?>
		</div>
		<?php
	}
}

if ( ! function_exists( 'xena_add_footer_info' ) ) {
	add_action( 'xena_credits', 'xena_add_footer_info' );
	/**
	 * Add the copyright to the footer
	 *
	 * @since 1.0.0
	 */
	function xena_add_footer_info() {
		$copyright = sprintf(
			'<span class="copyright">&copy; %1$s %2$s</span> &bull; %4$s <a href="%3$s" itemprop="url">%5$s</a>',
			date_i18n( __( 'Y', 'xena' ) ),
			get_bloginfo( 'name' ),
			esc_url( 'https://wpkind.com/' ),
			esc_html_x( 'Theme', 'Theme', 'xena' ),
			esc_html__( 'Xena', 'xena' )
		);

		echo apply_filters( 'xena_copyright', $copyright ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
	}
}

/**
 * Build our individual footer widgets.
 * Displays a sample widget if no widget is found in the area.
 *
 * @since 1.0.0
 *
 * @param int $widget_width The width class of our widget.
 * @param int $widget The ID of our widget.
 */
function xena_do_footer_widget( $widget_width, $widget ) {
	$widget_width        = apply_filters( "xena_footer_widget_{$widget}_width", $widget_width );
	$tablet_widget_width = apply_filters( "xena_footer_widget_{$widget}_tablet_width", '50' );
	?>
	<div class="footer-widget-<?php echo absint( $widget ); ?> grid-parent grid-<?php echo absint( $widget_width ); ?> tablet-grid-<?php echo absint( $tablet_widget_width ); ?> mobile-grid-100">
		<?php dynamic_sidebar( 'footer-' . absint( $widget ) ); ?>
	</div>
	<?php
}

if ( ! function_exists( 'xena_construct_footer_widgets' ) ) {
	add_action( 'xena_footer', 'xena_construct_footer_widgets', 5 );
	/**
	 * Build our footer widgets.
	 *
	 * @since 1.0.0
	 */
	function xena_construct_footer_widgets() {
		// Get how many widgets to show.
		$widgets = xena_get_footer_widgets();

		if ( ! empty( $widgets ) && '0' !== $widgets ) :

			// If no footer widgets exist, we don't need to continue.
			if (
				! is_active_sidebar( 'footer-1' ) &&
				! is_active_sidebar( 'footer-2' ) &&
				! is_active_sidebar( 'footer-3' ) &&
				! is_active_sidebar( 'footer-4' ) &&
				! is_active_sidebar( 'footer-5' ) ) {
				return;
			}

			// Set up the widget width.
			$widget_width = '';
			if ( '1' === $widgets ) {
				$widget_width = '100';
			}

			if ( '2' === $widgets ) {
				$widget_width = '50';
			}

			if ( '3' === $widgets ) {
				$widget_width = '33';
			}

			if ( '4' === $widgets ) {
				$widget_width = '25';
			}

			if ( '5' === $widgets ) {
				$widget_width = '20';
			}
			?>
			<div id="footer-widgets" class="site footer-widgets">
				<div <?php xena_do_element_classes( 'inside_footer' ); ?>>
					<div class="inside-footer-widgets">
						<?php
						if ( $widgets >= 1 ) {
							xena_do_footer_widget( $widget_width, 1 );
						}

						if ( $widgets >= 2 ) {
							xena_do_footer_widget( $widget_width, 2 );
						}

						if ( $widgets >= 3 ) {
							xena_do_footer_widget( $widget_width, 3 );
						}

						if ( $widgets >= 4 ) {
							xena_do_footer_widget( $widget_width, 4 );
						}

						if ( $widgets >= 5 ) {
							xena_do_footer_widget( $widget_width, 5 );
						}
						?>
					</div>
				</div>
			</div>
			<?php
		endif;

		/**
		 * Xena_after_footer_widgets hook.
		 *
		 * @since 1.0.0
		 */
		do_action( 'xena_after_footer_widgets' );
	}
}

if ( ! function_exists( 'xena_back_to_top' ) ) {
	add_action( 'xena_after_footer', 'xena_back_to_top' );
	/**
	 * Build the back to top button
	 *
	 * @since 1.0.0
	 */
	function xena_back_to_top() {
		$xena_settings = wp_parse_args(
			get_option( 'xena_settings', array() ),
			xena_get_defaults()
		);

		if ( 'enable' !== $xena_settings['back_to_top'] ) {
			return;
		}

		echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			'xena_back_to_top_output',
			sprintf( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				'<a title="%1$s" rel="nofollow" href="#" class="xena-back-to-top" style="opacity:0;visibility:hidden;" data-scroll-speed="%2$s" data-start-scroll="%3$s">
				<span class="screen-reader-text">%5$s</span>
				%6$s
			</a>',
				esc_attr__( 'Scroll back to top', 'xena' ),
				absint( apply_filters( 'xena_back_to_top_scroll_speed', 400 ) ),
				absint( apply_filters( 'xena_back_to_top_start_scroll', 300 ) ),
				esc_attr( apply_filters( 'xena_back_to_top_icon', 'fa-angle-up' ) ),
				esc_html__( 'Scroll back to top', 'xena' ),
				xena_get_svg_icon( 'arrow' )
			) 
		);
	}
}
