<?php
/**
 * Navigation elements.
 *
 * @package Xena
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! function_exists( 'xena_navigation_position' ) ) {
	/**
	 * Build the navigation.
	 *
	 * @since 1.0.0
	 */
	function xena_navigation_position() {
		?>
		<nav id="site-navigation" <?php xena_do_element_classes( 'navigation' ); ?> <?php xena_do_microdata( 'navigation' ); ?>>
			<div <?php xena_do_element_classes( 'inside_navigation' ); ?>>
				<?php
				/**
				 * Xena_inside_navigation hook.
				 *
				 * @since 1.0.0
				 *
				 * @hooked xena_navigation_search - 10
				 * @hooked xena_mobile_menu_search_icon - 10
				 */
				do_action( 'xena_inside_navigation' );
				?>
				<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
					<?php
					/**
					 * Xena_inside_mobile_menu hook.
					 *
					 * @since 1.0.0
					 */
					do_action( 'xena_inside_mobile_menu' );

					xena_do_svg_icon( 'menu-bars', true );

					$mobile_menu_label = apply_filters( 'xena_mobile_menu_label', esc_html__( 'Menu', 'xena' ) );

					if ( $mobile_menu_label ) {
						printf(
							'<span class="mobile-menu">%s</span>',
							esc_html( $mobile_menu_label )
						);
					} else {
						printf(
							'<span class="screen-reader-text">%s</span>',
							esc_html__( 'Menu', 'xena' )
						);
					}
					?>
				</button>
				<?php
				wp_nav_menu(
					array(
						'theme_location'  => 'primary',
						'container'       => 'div',
						'container_class' => 'main-nav',
						'container_id'    => 'primary-menu',
						'menu_class'      => '',
						'fallback_cb'     => 'xena_menu_fallback',
						'items_wrap'      => '<ul id="%1$s" class="%2$s ' . join( ' ', xena_get_element_classes( 'menu' ) ) . '">%3$s</ul>',
					)
				);

				/**
				 * Xena_after_primary_menu hook.
				 *
				 * @since 1.0.0
				 */
				do_action( 'xena_after_primary_menu' );
				?>
			</div><!-- .inside-navigation -->
		</nav><!-- #site-navigation -->
		<?php
	}
}

if ( ! function_exists( 'xena_menu_fallback' ) ) {
	/**
	 * Menu fallback.
	 *
	 * @since 1.1.4
	 *
	 * @param  array $args args.
	 */
	function xena_menu_fallback( $args ) {
		$xena_settings = wp_parse_args(
			get_option( 'xena_settings', array() ),
			xena_get_defaults()
		);
		?>
		<div id="primary-menu" class="main-nav">
			<ul <?php xena_do_element_classes( 'menu' ); ?>>
				<?php
				$args = array(
					'sort_column' => 'menu_order',
					'title_li'    => '',
					'walker'      => new Xena_Page_Walker(),
				);

				wp_list_pages( $args );

				if ( 'enable' === $xena_settings['nav_search'] ) {
					printf(
						'<li class="search-item"><a aria-label="%1$s" href="#">%2$s</a></li>',
						esc_attr__( 'Open Search Bar', 'xena' ),
						xena_get_svg_icon( 'search', true ) // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
					);
				}
				?>
			</ul>
		</div><!-- .main-nav -->
		<?php
	}
}

/**
 * Generate the navigation based on settings
 *
 * It would be better to have all of these inside one action, but these
 * are kept this way to maintain backward compatibility for people
 * un-hooking and moving the navigation/changing the priority.
 *
 * @since 1.0.0
 */

if ( ! function_exists( 'xena_add_navigation_after_header' ) ) {
	add_action( 'xena_after_header', 'xena_add_navigation_after_header', 5 );
	/**Xena add navigation after header
	 */
	function xena_add_navigation_after_header() {
		if ( 'nav-below-header' === xena_get_navigation_location() ) {
			xena_navigation_position();
		}
	}
}

if ( ! function_exists( 'xena_add_navigation_before_header' ) ) {
	add_action( 'xena_before_header', 'xena_add_navigation_before_header', 5 );

	/**Xena add navigation before header
	 */
	function xena_add_navigation_before_header() {
		if ( 'nav-above-header' === xena_get_navigation_location() ) {
			xena_navigation_position();
		}
	}
}

if ( ! function_exists( 'xena_add_navigation_float_right' ) ) {
	add_action( 'xena_after_header_content', 'xena_add_navigation_float_right', 5 );
	/**
	 * Xena add navigation float right
	 */
	function xena_add_navigation_float_right() {
		if ( 'nav-float-right' === xena_get_navigation_location() || 'nav-float-left' === xena_get_navigation_location() ) {
			xena_navigation_position();
		}
	}
}

if ( ! function_exists( 'xena_add_navigation_before_right_sidebar' ) ) {
	add_action( 'xena_before_right_sidebar_content', 'xena_add_navigation_before_right_sidebar', 5 );
	
	/**
	 * Xena add navigation before right sidebar
	 */
	function xena_add_navigation_before_right_sidebar() {
		if ( 'nav-right-sidebar' === xena_get_navigation_location() ) {
			echo '<div class="gen-sidebar-nav">';
				xena_navigation_position();
			echo '</div>';
		}
	}
}

if ( ! function_exists( 'xena_add_navigation_before_left_sidebar' ) ) {
	add_action( 'xena_before_left_sidebar_content', 'xena_add_navigation_before_left_sidebar', 5 );

	/**Xena add navigation before left sidebar
	 */
	function xena_add_navigation_before_left_sidebar() {
		if ( 'nav-left-sidebar' === xena_get_navigation_location() ) {
			echo '<div class="gen-sidebar-nav">';
				xena_navigation_position();
			echo '</div>';
		}
	}
}


if ( ! function_exists( 'xena_dropdown_icon_to_menu_link' ) ) {
	add_filter( 'nav_menu_item_title', 'xena_dropdown_icon_to_menu_link', 10, 4 );
	/**
	 * Add dropdown icon if menu item has children.
	 *
	 * @since 1.0.0
	 *
	 * @param string   $title The menu item title.
	 * @param WP_Post  $item All of our menu item data.
	 * @param stdClass $args All of our menu item args.
	 * @param int      $depth Depth of menu item.
	 * @return string The menu item.
	 */
	function xena_dropdown_icon_to_menu_link( $title, $item, $args, $depth ) {
		$role     = 'presentation';
		$tabindex = '';

		if ( 'click-arrow' === xena_get_option( 'nav_dropdown_type' ) ) {
			$role     = 'button';
			$tabindex = ' tabindex="0"';
		}

		if ( isset( $args->container_class ) && 'main-nav' === $args->container_class ) {
			foreach ( $item->classes as $value ) {
				if ( 'menu-item-has-children' === $value ) {
					$icon  = xena_get_svg_icon( 'arrow' );
					$title = $title . '<span role="' . $role . '" class="dropdown-menu-toggle"' . $tabindex . '>' . $icon . '</span>';
				}
			}
		}

		return $title;
	}
}

if ( ! function_exists( 'xena_navigation_search' ) ) {
	add_action( 'xena_inside_navigation', 'xena_navigation_search' );
	/**
	 * Add the search bar to the navigation.
	 *
	 * @since 1.1.4
	 */
	function xena_navigation_search() {
		$xena_settings = wp_parse_args(
			get_option( 'xena_settings', array() ),
			xena_get_defaults()
		);

		if ( 'enable' !== $xena_settings['nav_search'] ) {
			return;
		}

		echo apply_filters( // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
			'xena_navigation_search_output',
			sprintf(
				'<form method="get" class="search-form navigation-search" action="%1$s">
				<input type="search" class="search-field" value="%2$s" name="s" title="%3$s" />
			</form>',
				esc_url( home_url( '/' ) ),
				esc_attr( get_search_query() ),
				esc_attr_x( 'Search', 'label', 'xena' )
			)
		);
	}
}

if ( ! function_exists( 'xena_menu_search_icon' ) ) {
	add_filter( 'wp_nav_menu_items', 'xena_menu_search_icon', 10, 2 );
	/**
	 * Add search icon to primary menu if set
	 *
	 * @since 1.0.0
	 *
	 * @param string   $nav The HTML list content for the menu items.
	 * @param stdClass $args An object containing wp_nav_menu() arguments.
	 * @return string The search icon menu item.
	 */
	function xena_menu_search_icon( $nav, $args ) {
		$xena_settings = wp_parse_args(
			get_option( 'xena_settings', array() ),
			xena_get_defaults()
		);

		// If the search icon isn't enabled, return the regular nav.
		if ( 'enable' !== $xena_settings['nav_search'] ) {
			return $nav;
		}

		// If our primary menu is set, add the search icon.
		if ( isset( $args->theme_location ) && 'primary' === $args->theme_location ) {
			return sprintf(
				'%1$s<li class="search-item"><a aria-label="%2$s" href="#">%3$s</a></li>',
				$nav,
				esc_attr__( 'Open Search Bar', 'xena' ),
				xena_get_svg_icon( 'search', true )
			);
		}

		// Our primary menu isn't set, return the regular nav.
		// In this case, the search icon is added to the xena_menu_fallback() function in navigation.php.
		return $nav;
	}
}

if ( ! function_exists( 'xena_mobile_menu_search_icon' ) ) {
	add_action( 'xena_inside_navigation', 'xena_mobile_menu_search_icon' );
	/**
	 * Add search icon to mobile menu bar
	 *
	 * @since 1.3.12
	 */
	function xena_mobile_menu_search_icon() {
		$xena_settings = wp_parse_args(
			get_option( 'xena_settings', array() ),
			xena_get_defaults()
		);

		// If the search icon isn't enabled, return the regular nav.
		if ( 'enable' !== $xena_settings['nav_search'] ) {
			return;
		}

		?>
		<div class="mobile-bar-items">
			<?php do_action( 'xena_inside_mobile_menu_bar' ); ?>
			<span class="search-item">
				<a aria-label="<?php esc_attr_e( 'Open Search Bar', 'xena' ); ?>" href="#">
					<?php xena_do_svg_icon( 'search', true ); ?>
				</a>
			</span>
		</div><!-- .mobile-bar-items -->
		<?php
	}
}

add_action( 'wp_footer', 'xena_clone_sidebar_navigation' );
/**
 * Clone our sidebar navigation and place it below the header.
 * This places our mobile menu in a more user-friendly location.
 *
 * We're not using wp_add_inline_script() as this needs to happens
 * before menu.js is enqueued.
 *
 * @since 1.0.0
 */
function xena_clone_sidebar_navigation() {
	if ( 'nav-left-sidebar' !== xena_get_navigation_location() && 'nav-right-sidebar' !== xena_get_navigation_location() ) {
		return;
	}
	?>
	<script>
		var target, nav, clone;
		nav = document.getElementById( 'site-navigation' );
		if ( nav ) {
			clone = nav.cloneNode( true );
			clone.className += ' sidebar-nav-mobile';
			clone.setAttribute( 'aria-label', '<?php esc_attr_e( 'Mobile Menu', 'xena' ); ?>' );
			target = document.getElementById( 'masthead' );
			if ( target ) {
				target.insertAdjacentHTML( 'afterend', clone.outerHTML );
			} else {
				document.body.insertAdjacentHTML( 'afterbegin', clone.outerHTML )
			}
		}
	</script>
	<?php
}
